GraphPairCombinator
===================

.. currentmodule:: pykeen.datasets.ea.combination

.. autoclass:: GraphPairCombinator
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~GraphPairCombinator.__call__
      ~GraphPairCombinator.process

   .. rubric:: Methods Documentation

   .. automethod:: __call__
   .. automethod:: process
